# Axon Synthesis

A package to synthesize artificial axons.

The main documentation, is available here: [https://axon-synthesis.readthedocs.io](https://axon-synthesis.readthedocs.io)


### Installation

It is recommended to install ``axon-synthesis`` using [pip](https://pip.pypa.io/en/stable/):

```bash
pip install axon-synthesis
```


### Examples

An example can be found in the ``examples`` directory.
This example contains a small input dataset and a ``run.sh`` script that will execute the code.
The inputs can be reviewed and modified for testing.


### Citation

When you use the ``axon-synthesis`` software or method for your research, we ask you to cite the
publication associated to this repository (use the ``Cite this repository`` button on the
[main page](https://github.com/BlueBrain/axon-synthesis) of the code).


### Funding & Acknowledgment

The development of this software was supported by funding to the Blue Brain Project, a research
center of the École polytechnique fédérale de Lausanne (EPFL), from the Swiss government’s ETH
Board of the Swiss Federal Institutes of Technology.

For license and authors, see `LICENSE.txt` and `AUTHORS.md` respectively.

Copyright © 2023-2024 Blue Brain Project, EPFL
